<?php

class FleetMovements {

	private $dbcon;							// database connection object
	private $fleetmovetable;				// database table name for fleet movements
	private $flipped_probe_array;			// needed to get translated entity list
	private $ogame_offset;                  // time difference between ogame server and user

	function __construct($dbcon,$fleetmovetable,array $flipped_probe_array) {
		if (!isset($dbcon) || $dbcon == null || !$dbcon) {
			return false;
		}
		$this->dbcon = $dbcon;

		if (empty($fleetmovetable)) return false;
		$this->fleetmovetable = $fleetmovetable;

		if (count($flipped_probe_array) == 0) return false;
		$this->flipped_probe_array = $flipped_probe_array;

		if (!isset($_SESSION['s_ogame_offset']) || $_SESSION['s_ogame_offset'] == "+00:00") {
			$this->ogame_offset = 0;
		} else {
			$hour_minutes       = explode(":",$_SESSION['s_ogame_offset']);
			$this->ogame_offset = intval($hour_minutes[0]);
			if ($hour_minutes[1] == "30") {
				if ($this->ogame_offset < 0) {
					$this->ogame_offset -= 0.5;
				} else {
					$this->ogame_offset += 0.5;
				}
			}
		}

	}

	/**
	 * Delete fleet by ID
	 *
	 * @param Mysql Connection $dbcon
	 * @param String $fleetmovetable database table name for fleet movements
	 * @param int $id Internal ID
	 */
	static public function delete_fleet($dbcon, $fleetmovetable, $fleet_id, $sub_fleet_id) {
		$fleet_id     = intval($fleet_id);
		$sub_fleet_id = intval($sub_fleet_id);

		if ($fleet_id < 1) return false;
		if ($sub_fleet_id > 0) $where = "AND sub_fleet_id='$sub_fleet_id'";
		else $where = "AND sub_fleet_id=0"; // to make sure that no parts of ACS fleet are deleted

		$query = "DELETE FROM $fleetmovetable WHERE fleet_id='$fleet_id' $where";
		$res = mysql_query($query,$dbcon) or die(mysql_error($dbcon));

		return true;
	}


	/**
	 * Get all fleet movements from database sorted by arrival time.
	 *
	 * @return Array of Fleets
	 */
	public function fetch_all() {
		$query = "SELECT * FROM $this->fleetmovetable";
		$res = mysql_query($query,$this->dbcon) or die(mysql_error($this->dbcon));
		return $this->create_fleet_array($res);
	}

	/**
	 * Get specific fleet movement from database
	 *
	 * @param int $fleet_id
	 * @return Array with one fleet
	 */
	public function fetch_fleet($fleet_id) {
		$fleet_id = intval($fleet_id);
		if ($fleet_id < 1) return false;
		$query = "SELECT * FROM $this->fleetmovetable WHERE fleet_id='$fleet_id'";
		$res = mysql_query($query,$this->dbcon) or die(mysql_error($this->dbcon));
		return $this->create_fleet_array($res);
	}

	/**
	 * Get fleet movements for a specific planet
	 *
	 * @param int $galaxy
	 * @param int $system
	 * @param int $planet
	 * @return Array of fleets
	 */
	public function fetch_planet($galaxy,$system,$planet) {
		$galaxy = intval($galaxy);
		$system = intval($system);
		$planet = intval($planet);
		if ($galaxy < 1) return false;
		if ($system < 1) return false;
		if ($planet < 1) return false;

		$query = "SELECT * FROM $this->fleetmovetable WHERE ".
		"origin_galaxy='$galaxy' AND origin_system='$system' AND origin_planet='$planet' OR ".
		"destination_galaxy='$galaxy' AND destination_system='$system' AND destination_planet='$planet'";
		$res = mysql_query($query,$this->dbcon) or die(mysql_error($this->dbcon));

		return $this->create_fleet_array($res);
	}

	/**
	 * Check if there are any fleet movements within a given system.
	 *
	 * @param int $galaxy
	 * @param int $system
	 * @return Array with 16 entries, 1-15 reflect planets and have true or false
	 */
	public function check_fleet_movement($galaxy,$system) {
		$galaxy = intval($galaxy);
		$system = intval($system);
		if ($galaxy < 1) return false;
		if ($system < 1) return false;

		$query = "SELECT origin_galaxy, origin_system, origin_planet, destination_galaxy, destination_system, destination_planet ".
		"FROM $this->fleetmovetable ".
		"WHERE origin_galaxy=$galaxy and origin_system=$system OR destination_galaxy=$galaxy AND destination_system=$system";
		$res = mysql_query($query,$this->dbcon) or die(mysql_error($this->dbcon));

		$fleet_moves = array();
		for ($i=0;$i<=15;$i++) {
			$fleet_moves[$i] = false;
		}
		while($line = mysql_fetch_object($res)) {
			if ($line->origin_galaxy == $galaxy && $line->origin_system == $system) {
				$fleet_moves[$line->origin_planet] = true;
			}
			if ($line->destination_galaxy == $galaxy && $line->destination_system == $system) {
				$fleet_moves[$line->destination_planet] = true;
			}
		}
		return $fleet_moves;
	}


	/**
	 * Standard output format used to display fleet movements without details.
	 *
	 * @param array $fleets
	 * @return String HTML content
	 */
	public function get_formated_output(array $fleets) {
		$output = '<table cellpadding="1" cellspacing="0" border="0" align="center" width="90%">'."\n".
		'<tr><td>'."\n".
		'<table id="fleet_movement_table" class="standard" cellpadding="4" cellspacing="0" border="0" width="100%">'."\n".
		'<tr class="tblhead"><td colspan="9">'.FLEETS_ACTUAL_FLEETS.'</td></tr>'."\n";

		if (count($fleets) == 0) {
			$output .= '<tr class="firstcolor"><td colspan="9">'.FLEETS_NO_DATA.'</td></tr>'."\n";
			$output .= '</table>'."\n".
			'</td></tr>'."\n".
			'</table>'."\n";
			return $output;
		}

		$i = 0;
		foreach ($fleets as $line) {
			$returning = ($line['returning'] == "true") ? FLEETS_YES : FLEETS_NO;
			$mission = $this->get_mission($line['mission']);
			// create array containing fleet text and amount if amount > 0
			$entities = $this->get_entities($line);
			$details = htmlentities('<table class=\"standard\" cellpadding=\"4\" cellspacing=\"0\" border=\"0\" width=\"100%\">'.
			'<tr class=\"tblhead\"><td colspan=\"4\">').utf8_encode(FLEETS_DETAILS).htmlentities(" ["). $line['scantime'] .htmlentities("]").htmlentities('</td></tr>');

			foreach ($entities as $j => $entity) {
				$entity[1] = number_format($entity[1],0,",",".");
				if ($j % 2 == 0) {
					$details .= htmlentities('<tr class=\"firstcolor\"><td style=\"padding-left:20px;\">').utf8_encode($entity[0]).htmlentities(':</td><td>'.$entity[1].'</td>');
				} else {
					$details .= htmlentities('<td>').utf8_encode($entity[0]).htmlentities(':</td><td>'.$entity[1].'</td></tr>');
				}
			}
			if ($j % 2 == 0) {
				// we need to add an empty fleet entry
				$details .= htmlentities('<td colspan=\"2\">&nbsp;</td></tr>');
			}
			$details .= htmlentities('</table></td></tr></table>');

			// $js_code = 'onmouseover="ShowLocalObject(\'popup\',\''.$details.'\')"'; <-- was not reliable with showing up the entry
			$js_code = 'onmouseover=\'this.T_WIDTH=350;return escape("'.$details.'")\'';

			if ($i % 2 == 0) {
				$class = "firstcolor";
			} else {
				$class = "secondcolor";
			}

			if ($line['returning'] == "true") {
				$ship_icon = '<a href="fleet_movements.php?fleet_id='.$line['fleet_id'].'"><img border="0" '.$js_code.' src="../images/spaceship_left.png" /></a>';
			} else {
				$ship_icon = '<a href="fleet_movements.php?fleet_id='.$line['fleet_id'].'"><img border="0" '.$js_code.' src="../images/spaceship_right.png" /></a>';
			}

			// planet icons
			$origin_planet_icon      = $this->get_planet_icon($line['origin_moon']);
			$destination_planet_icon = $this->get_planet_icon($line['destination_moon']);

			$arrival_time = explode(" ",$line['arrival_time']);
			$output .= '<tr id="fleet_'.$line['fleet_id']."_".$line['sub_fleet_id'].'" class="'.$class.'">'.
			'<td style="padding-left:20px;">'.$arrival_time[1]."<br />".$arrival_time[0]."</td>".
			'<td>'.$mission."</td>".
			"<td>$origin_planet_icon</td>".
			"<td>".$line['origin_planetname']."<br /><a class=\"link\" href=\"view.php?gala=".$line['origin_galaxy']."&amp;system=".$line['origin_system']."\">".$line['origin_galaxy'].":".$line['origin_system'].":".$line['origin_planet']."</a></td>\n".
			"<td>".$ship_icon."</td>".
			"<td>".number_format($line['ships'],0,",",".")."</td>".
			"<td>$destination_planet_icon</td>".
			'<td>'.$line['destination_planetname']."<br /><a class=\"link\" href=\"view.php?gala=".$line['destination_galaxy']."&amp;system=".$line['destination_system']."\">".$line['destination_galaxy'].":".$line['destination_system'].":".$line['destination_planet']."</a></td>";

			if (isset($_SESSION['s_candelete']) && $_SESSION['s_candelete'] === true) {
				$output .= "<td><a href=\"#\"><img src=\"../images/trash.png\" onclick=\"deleteFleetMovement('".$line['fleet_id']."','".$line['sub_fleet_id']."')\" border=\"0\" /></a></td>";
			} else {
				$output .= "<td>&nbsp;</td>";
			}
			$output .= "</tr>\n";

			$i++;
		}

		$output .= '</table>'."\n".
		'</td></tr>'."\n".
		'</table>'."\n";

		return $output;
	}

	/**
	 * Standard output format used to display a single fleet.
	 *
	 * @param array $line
	 * @param int $acs_fleet_no This parameter is used to specify the fleet number used for drago-sim link creation
	 * @param String $dragosim_acs_link This is the url generated for dragosim to simulate ACS attacks
	 * @return String HTML output
	 */
	public function get_single_formated_output(array $line,$dragosim_acs_link="") {
		if (!isset($line['origin_galaxy'])) return false; // wrong array type provided

		$arrival_time = explode(" ",$line['arrival_time']);

		$output = '<table id="fleet_'.$line['fleet_id']."_".$line['sub_fleet_id'].'" cellpadding="1" cellspacing="0" border="0" align="center" width="90%">'."\n".
		'<tr><td>'."\n".
		'<table class="standard" cellpadding="4" cellspacing="0" border="0" width="100%">'."\n".
		'<tr class="tblhead"><td colspan="9">'.FLEETS_DETAILS." [".$line['scantime']."]".'</td></tr>'."\n";

		if ($dragosim_acs_link != "") {
			$output .= '<tr class="tblhead"><td><span class="acs_attack">'.FLEETS_MISSION_ACS_ATTACK."</span></td>".
			'<td colspan="8"><a class="resultlink" href="'.$dragosim_acs_link.'"  target="dragosim">'.REPORTS_DRAGOSIM.'</a></td></tr>'."\n";
		}

		$returning = ($line['returning'] == "true") ? FLEETS_YES : FLEETS_NO;
		$mission = $this->get_mission($line['mission']);
		// create array containing fleet text and amount if amount > 0
		$entities = $this->get_entities($line);
		$speedsim_link = $this->get_speedsimlink($line);
		$dragosim_link = $this->get_dragosimlink($line);

		if ($line['returning'] == "true") {
			$ship_icon = '<img src="../images/spaceship_left.png" />';
		} else {
			$ship_icon = '<img src="../images/spaceship_right.png" />';
		}

		// planet icons
		$origin_planet_icon      = $this->get_planet_icon($line['origin_moon']);
		$destination_planet_icon = $this->get_planet_icon($line['destination_moon']);


		$output .= '<tr class="firstcolor">'.
		'<td style="padding-left:20px;">'.$arrival_time[1]."<br />".$arrival_time[0]."</td>".
		'<td>'.$mission."</td>".
		"<td>$origin_planet_icon</td>".
		"<td>".$line['origin_planetname']."<br /><a class=\"link\" href=\"view.php?gala=".$line['origin_galaxy']."&amp;system=".$line['origin_system']."\">".$line['origin_galaxy'].":".$line['origin_system'].":".$line['origin_planet']."</a></td>\n".
		"<td>".$ship_icon."</td>".
		"<td>".number_format($line['ships'],0,",",".")."</td>".
		"<td>$destination_planet_icon</td>".
		'<td>'.$line['destination_planetname']."<br /><a class=\"link\" href=\"view.php?gala=".$line['destination_galaxy']."&amp;system=".$line['destination_system']."\">".$line['destination_galaxy'].":".$line['destination_system'].":".$line['destination_planet']."</a></td>";
		if (isset($_SESSION['s_candelete']) && $_SESSION['s_candelete'] === true) {
			$output .= "<td><a href=\"#\"><img src=\"../images/trash.png\" onclick=\"deleteFleetMovement('".$line['fleet_id']."','".$line['sub_fleet_id']."')\" border=\"0\" /></a></td>";
		}
		$output .= "</tr>\n";

		$output .= '<tr><td colspan="9">';

		$output .= '<table class="standard" cellpadding="0" cellspacing="0" border="0" align="center" style="width:430px;">';

		$j = 0;
		foreach ($entities as $j => $entity) {
			$entity[1] = number_format($entity[1],0,",",".");
			if ($j % 2 == 0) {
				$output .= '<tr class="firstcolor"><td style="padding-left:20px; width:125px;">'.$entity[0].':</td><td style="width:70px;">'.$entity[1].'</td>';
			} else {
				$output .= '<td style="padding-left:20px; width:125px;">'.$entity[0].':</td><td style="width:70px;">'.$entity[1].'</td></tr>';
			}
		}
		if ($j % 2 == 0) {
			// we need to add an empty fleet entry
			$output .= '<td colspan="2">&nbsp;</td></tr>';
		}

		$output .= "<tr><td class=\"tblhead\" colspan=\"2\"><a class=\"resultlink\" href=\"$speedsim_link\"  target=\"speedsim\">".REPORTS_SPEEDSIM."</a></td><td class=\"tblhead\" colspan=\"2\"><a class=\"resultlink\" href=\"$dragosim_link\"  target=\"dragosim\">".REPORTS_DRAGOSIM."</a></td></tr>";

		$output .= '</table></td></tr>';

		$output .= '</table>'."\n".
		'</td></tr>'."\n".
		'</table>'."\n";
		return $output;

	}

	/**
	 * Standard output format used to display fleet movements for ACS attack
	 *
	 * @param array $fleets
	 * @return String HTML content
	 */
	public function get_acs_formated_output(array $fleets) {
		$output = "";

		$dragosim_acs_link = $this->get_dragosim_acs_link($fleets);

		foreach ($fleets as $line) {
			$output .= $this->get_single_formated_output($line,$dragosim_acs_link);

			$dragosim_acs_link = ""; // to have this displayed only once
		}

		return $output;
	}

	/**
	 * Transfer database request into internal array format and sort by arrival time.
	 *
	 * @param MySQL result $res
	 * @return Array of Fleets
	 */
	private function create_fleet_array($res) {
		$fleets = array();
		while ($line = mysql_fetch_assoc($res)) {

			$line['ships'] = $line['kt'] + $line['gt'] + $line['lj'] + $line['sj'] + $line['krz'] + $line['ss'] + $line['kolo'] + $line['rec'] + $line['spio'] + $line['bomb'] + $line['zerri'] + $line['ds'] + $line['skrz'] + $line['irak'];

			// calculate arrival time according to user Ogame offset settings
			$timestamp = strtotime($line['arrival_time']) + $this->ogame_offset * 3600;
			$line['arrival_time'] = date("Y-m-d H:i:s",$timestamp);

			// same for scantime
			$timestamp = strtotime($line['scantime']) + $this->ogame_offset * 3600;
			$line['scantime'] = date("Y-m-d H:i:s",$timestamp);

			$fleets[] = $line;

			// store column to allow sorting
			$arrival_time[]  = $line['arrival_time'];
		}
		if (count($fleets) == 0) return $fleets;

		// sort data
		array_multisort($arrival_time, SORT_ASC, $fleets);

		return $fleets;
	}

	/**
	 * Return HTML content for human readable mission description
	 *
	 * @param String $mission
	 * @return String HTML content
	 */
	private function get_mission($mission) {
		switch($mission) {
			case 'expedition':       return '<span class="expedition">'.FLEETS_MISSION_EXPEDITION."</span>"; break;
			case 'colonization':     return '<span class="colonization">'.FLEETS_MISSION_COLONIZATION."</span>"; break;
			case 'recycle':          return '<span class="recycle">'.FLEETS_MISSION_RECYCLE."</span>"; break;
			case 'transport':        return '<span class="transport">'.FLEETS_MISSION_TRANSPORT."</span>"; break;
			case 'deployment':       return '<span class="deployment">'.FLEETS_MISSION_DEPLOYMENT."</span>"; break;
			case 'espionage':        return '<span class="espionage">'.FLEETS_MISSION_ESPIONAGE."</span>"; break;
			case 'acs_defend':       return '<span class="acs_defend">'.FLEETS_MISSION_ACS_DEFEND."</span>"; break;
			case 'attack':           return '<span class="attack">'.FLEETS_MISSION_ATTACK."</span>"; break;
			case 'acs_attack':       return '<span class="acs_attack">'.FLEETS_MISSION_ACS_ATTACK."</span>"; break;
			case 'moon_destruction': return '<span class="moon_destruction">'.FLEETS_MISSION_MOON_DESTRUCTION."</span>"; break;
			case 'missile_attack':   return '<span class="missile_attack">'.FLEETS_MISSION_MISSILE_ATTACK."</span>"; break;
		}
	}


	private function get_planet_icon($planetinfo) {
		switch ($planetinfo) {
			case 'false':
				return "<img src=\"../images/planet.png\" />";
			case 'true':
				return "<img src=\"../images/moon.png\" />";
			default:
				return "<img src=\"../images/questionmark.png\" />";
		}
	}

	/**
	 * Convert internal fleet array into a list of entities with translated shipname and quantity if quantity > 0.
	 *
	 * @param Array $line Line of Fleet Array
	 * @return Array of entities with name and quantity
	 */
	private function get_entities(array $line) {

		$kt_text    = F_SMALLCARGOSHIP;
		$gt_text    = F_LARGECARGOSHIP;
		$lj_text    = F_LIGHFIGHTER;
		$sj_text    = F_HEAVYFIGHTER;
		$krz_text   = F_CRUISER;
		$ss_text    = F_BATTLESHIP;
		$kolo_text  = F_COLONYSHIP;
		$rec_text   = F_RECYCLER;
		$spio_text  = F_ESPIONAGEPROBE;
		$bomb_text  = F_BOMBER;
		$zerri_text = F_DESTROYER;
		$ds_text    = F_DEATHSTAR;
		$skrz_text  = F_BATTLECRUISER;
		$irak_text  = D_INTERPLANETARYMISSILE;
		if ($_SESSION['lang'] != "english") {
			$kt_text    = $this->flipped_probe_array[F_SMALLCARGOSHIP];
			$gt_text    = $this->flipped_probe_array[F_LARGECARGOSHIP];
			$lj_text    = $this->flipped_probe_array[F_LIGHFIGHTER];
			$sj_text    = $this->flipped_probe_array[F_HEAVYFIGHTER];
			$krz_text   = $this->flipped_probe_array[F_CRUISER];
			$ss_text    = $this->flipped_probe_array[F_BATTLESHIP];
			$kolo_text  = $this->flipped_probe_array[F_COLONYSHIP];
			$rec_text   = $this->flipped_probe_array[F_RECYCLER];
			$spio_text  = $this->flipped_probe_array[F_ESPIONAGEPROBE];
			$bomb_text  = $this->flipped_probe_array[F_BOMBER];
			$zerri_text = $this->flipped_probe_array[F_DESTROYER];
			$ds_text    = $this->flipped_probe_array[F_DEATHSTAR];
			$skrz_text  = $this->flipped_probe_array[F_BATTLECRUISER];
			$irak_text  = $this->flipped_probe_array[D_INTERPLANETARYMISSILE];
		}

		// create array containing fleet text and amount if amount > 0
		$entities = array(); // initialize array
		if ($line['kt'] > 0)    $entities[] = array($kt_text,$line['kt']);
		if ($line['gt'] > 0)    $entities[] = array($gt_text,$line['gt']);
		if ($line['lj'] > 0)    $entities[] = array($lj_text,$line['lj']);
		if ($line['sj'] > 0)    $entities[] = array($sj_text,$line['sj']);
		if ($line['krz'] > 0)   $entities[] = array($krz_text,$line['krz']);
		if ($line['ss'] > 0)    $entities[] = array($ss_text,$line['ss']);
		if ($line['kolo'] > 0)  $entities[] = array($kolo_text,$line['kolo']);
		if ($line['rec'] > 0)   $entities[] = array($rec_text,$line['rec']);
		if ($line['spio'] > 0)  $entities[] = array($spio_text,$line['spio']);
		if ($line['bomb'] > 0)  $entities[] = array($bomb_text,$line['bomb']);
		if ($line['zerri'] > 0) $entities[] = array($zerri_text,$line['zerri']);
		if ($line['ds'] > 0)    $entities[] = array($ds_text,$line['ds']);
		if ($line['skrz'] > 0)  $entities[] = array($skrz_text,$line['skrz']);
		if ($line['irak'] > 0)  $entities[] = array($irak_text,$line['irak']);

		return $entities;
	}

	/**
	 * Create link for simulation at websim.speedsim.net
	 *
	 * @param Array $line Fleet entry
	 * @return String - URL
	 */
	private function get_speedsimlink($line) {
		$link = "";

		if ($line['kt'] > 0)    $link = update_speedsim_link($link,"kt",$line['kt'],true);
		if ($line['gt'] > 0)    $link = update_speedsim_link($link,"gt",$line['gt'],true);
		if ($line['lj'] > 0)    $link = update_speedsim_link($link,"lj",$line['lj'],true);
		if ($line['sj'] > 0)    $link = update_speedsim_link($link,"sj",$line['sj'],true);
		if ($line['krz'] > 0)   $link = update_speedsim_link($link,"krz",$line['krz'],true);
		if ($line['ss'] > 0)    $link = update_speedsim_link($link,"ss",$line['ss'],true);
		if ($line['kolo'] > 0)  $link = update_speedsim_link($link,"kolo",$line['kolo'],true);
		if ($line['rec'] > 0)   $link = update_speedsim_link($link,"rec",$line['rec'],true);
		if ($line['spio'] > 0)  $link = update_speedsim_link($link,"spio",$line['spio'],true);
		if ($line['bomb'] > 0)  $link = update_speedsim_link($link,"bomb",$line['bomb'],true);
		if ($line['zerri'] > 0) $link = update_speedsim_link($link,"zerri",$line['zerri'],true);
		if ($line['ds'] > 0)    $link = update_speedsim_link($link,"ds",$line['ds'],true);
		if ($line['skrz'] > 0)  $link = update_speedsim_link($link,"skrz",$line['skrz'],true);
		if ($line['irak'] > 0)  $link = update_speedsim_link($link,"irak",$line['irak'],true);

		return $link;
	}

	/**
	 * Create link for simulation at drago-sim.com
	 *
	 * @param Array $line Fleet entry
	 * @param Int $fleet_counter Fleet number starting with zero
	 * @return String - URL
	 */
	private function get_dragosimlink($line,$link="",$fleet_counter=0) {

		if ($line['kt'] > 0)    $link = update_dragosim_link($link,"kt",$line['kt'],false,$fleet_counter,true);
		if ($line['gt'] > 0)    $link = update_dragosim_link($link,"gt",$line['gt'],false,$fleet_counter,true);
		if ($line['lj'] > 0)    $link = update_dragosim_link($link,"lj",$line['lj'],false,$fleet_counter,true);
		if ($line['sj'] > 0)    $link = update_dragosim_link($link,"sj",$line['sj'],false,$fleet_counter,true);
		if ($line['krz'] > 0)   $link = update_dragosim_link($link,"krz",$line['krz'],false,$fleet_counter,true);
		if ($line['ss'] > 0)    $link = update_dragosim_link($link,"ss",$line['ss'],false,$fleet_counter,true);
		if ($line['kolo'] > 0)  $link = update_dragosim_link($link,"kolo",$line['kolo'],false,$fleet_counter,true);
		if ($line['rec'] > 0)   $link = update_dragosim_link($link,"rec",$line['rec'],false,$fleet_counter,true);
		if ($line['spio'] > 0)  $link = update_dragosim_link($link,"spio",$line['spio'],false,$fleet_counter,true);
		if ($line['bomb'] > 0)  $link = update_dragosim_link($link,"bomb",$line['bomb'],false,$fleet_counter,true);
		if ($line['zerri'] > 0) $link = update_dragosim_link($link,"zerri",$line['zerri'],false,$fleet_counter,true);
		if ($line['ds'] > 0)    $link = update_dragosim_link($link,"ds",$line['ds'],false,$fleet_counter,true);
		if ($line['skrz'] > 0)  $link = update_dragosim_link($link,"skrz",$line['skrz'],false,$fleet_counter,true);
		if ($line['irak'] > 0)  $link = update_dragosim_link($link,"irak",$line['irak'],false,$fleet_counter,true);

		return $link;
	}

	/**
	 * Create link for simulation of ACS battles at drago-sim.com
	 *
	 * @param Array $fleets Fleet entries
	 * @return String - URL
	 */
	private function get_dragosim_acs_link(array $fleets) {
		$dragosim_acs_link = "";

		$fleet_counter = 0;
		foreach ($fleets as $line) {
			$dragosim_acs_link = $this->get_dragosimlink($line,$dragosim_acs_link,$fleet_counter);
			$fleet_counter++;
		}
		return $dragosim_acs_link."&num[0]=".count($fleets);
	}

}

?>